* [Home](index.md)
* Examples
    * [Patent Deduplication](examples/patent_deduplication.ipynb)
* Concepts
    * [Goals and Alternatives](concepts/goals_and_alternatives.md)
    * [Fellegi-Sunter Model](concepts/fs.md)
    * [Versioning Policy](concepts/versioning.md)
* Reference
    * [Core API](reference/core.md)
    * By Task
        * [EDA](reference/eda.md)
        * [Joining](reference/join.md)
        * [Comparing](reference/compare.md)
            * [Fellegi-Sunter](reference/fs.md)
        * [Clustering](reference/cluster.md)
        * [Datasets](reference/datasets.md)
        * [Play Data](reference/playdata.md)
    * By Data Type
        * [Text Utils](reference/text.md)
        * [Array Utils](reference/arrays.md)
        * [Set Utils](reference/sets.md)
        * [Vector Utils](reference/vectors.md)
    * By Domain
        * [Geospatial](reference/lib/geo.md)
        * [Human Names](reference/lib/name.md)
        * [Emails](reference/lib/email.md)
        * [Phones](reference/lib/phone.md)
    * [Exceptions](reference/exceptions.md)
* [Contribute](contributing.md)
